@@ -21,6 +21,7 @@
 extern int errno;
 #endif
 
+
 extern GtkWidget *capplet;
 extern GtkWidget *setup_button;
 extern GtkWidget *setup_label;
@@ -186,18 +187,18 @@ create_list (GtkList *list, gchar *directory)
                 gchar *name;
 
                 name = listp->data;
-                prefix = g_copy_strings ("=", directory, name, "=/Desktop Entry/", NULL);
+                prefix = g_strconcat ("=", directory, name, "=/Desktop Entry/", NULL);
                 gnome_config_push_prefix (prefix);
                 g_free (prefix);
                 
                 sdnew = g_malloc (sizeof (screensaver_data));
-                sdnew->desktop_filename = g_copy_strings (directory, name, NULL);
+                sdnew->desktop_filename = g_strconcat (directory, name, NULL);
                 sdnew->name = gnome_config_get_translated_string ("Name");
                 sdnew->tryexec = gnome_config_get_string ("TryExec");
                 gnome_config_pop_prefix ();
                 sdnew->args = NULL;
                 
-                prefix = g_copy_strings ("=", directory, name, "=/Screensaver Data/", NULL);
+                prefix = g_strconcat ("=", directory, name, "=/Screensaver Data/", NULL);
                 gnome_config_push_prefix (prefix);
                 g_free (prefix);
                 sdnew->windowid = gnome_config_get_string ("WindowIdCommand");
@@ -212,7 +213,7 @@ create_list (GtkList *list, gchar *directory)
                                 g_free (prefix);
                         } else {
                                 /* we want to set up the initial settings */
-                                sdnew->icon = g_copy_strings (directory, prefix, NULL);
+                                sdnew->icon = g_strconcat (directory, prefix, NULL);
                                 
                                 g_free (prefix);
                         }
@@ -276,7 +277,7 @@ GtkWidget
                 gtk_list_set_selection_mode (GTK_LIST (list), GTK_SELECTION_BROWSE);
                 templist = g_list_prepend (templist, gtk_list_item_new_with_label ("No Screensaver"));
                 gtk_list_prepend_items (GTK_LIST (list), templist);
-                
+
                 //random = get_random_data ();
 
                 
@@ -346,14 +347,24 @@ launch_miniview (screensaver_data *sd)
         if (pid == 0) {
                 close (p[0]);
                 snprintf (xid, 11,"0x%x", GDK_WINDOW_XWINDOW (monitor->window));
-                temp = g_copy_strings (sd->demo, " ", sd->windowid, " ", xid, NULL);
+#ifdef HAVE_REDHAT_XSCREENSAVER_RPM
+                temp = g_strconcat ("/usr/X11R6/lib/xscreensaver/", sd->demo, " ", sd->windowid, " ", xid, NULL);
+#else
+                temp = g_strconcat (sd->demo, " ", sd->windowid, " ", xid, NULL);
+#endif
                 argv = g_strsplit (temp, " ", -1);
                 g_free (temp);
+#ifdef HAVE_REDHAT_XSCREENSAVER_RPM
+                execv (argv[0], argv);
+#else
+                
                 temp = gnome_is_program_in_path (argv[0]);
+                
                 if (temp == NULL)
                         _exit (0);
                         
                 execvp (temp, argv);
+#endif
                 /* This call should never return, but if it does... */
                 _exit (0);
         }
@@ -391,7 +402,7 @@ handle_list_change(void *data)
         sd = (screensaver_data *) data;
         if (sd->args == NULL)
                 init_screensaver_data (sd);
-        label = g_copy_strings (sd->name, _(" Settings"), NULL);
+        label = g_strconcat (sd->name, _(" Settings"), NULL);
         gtk_label_set (GTK_LABEL (setup_label),label);
         g_free (label);
         if ((sd->setup_data == NULL) || (sd->dialog != NULL))
@@ -539,8 +550,11 @@ dialog_callback (GtkWidget *dialog, gint button, screensaver_data *newsd)
                         return;
                 if (pid_big == 0) {
                         snprintf (xid, 11,"0x%x", GDK_WINDOW_XWINDOW (sswin));
-                        temp = g_copy_strings (newsd->args, " ", newsd->windowid, " ", xid, NULL);
-                        
+#ifdef HAVE_REDHAT_XSCREENSAVER_RPM                        
+                        temp = g_strconcat ("/usr/X11R6/lib/xscreensaver/", newsd->args, " ", newsd->windowid, " ", xid, NULL);
+#else
+                        temp = g_strconcat (newsd->args, " ", newsd->windowid, " ", xid, NULL);
+#endif
                         argv = g_strsplit (temp, " ", -1);
                         g_free (temp);
                         temp = gnome_is_program_in_path (argv[0]);
@@ -596,9 +610,12 @@ ok_callback ()
                 if (password)
                         g_string_append (command, " -lock-mode");
                 g_string_append (command," -xrm \"*programs:\t");
-                if (sd->args) {
+#ifdef HAVE_REDHAT_XSCREENSAVER_RPM
+                g_string_append (command, "/usr/X11R6/lib/xscreensaver/");
+#endif
+                if (sd->args && *(sd->args))
                         g_string_append (command, sd->args);
-                } else
+                else
                         g_string_append (command, sd->tryexec);
                 if (sd->root) {
                         g_string_append (command, " ");
@@ -607,6 +624,7 @@ ok_callback ()
                 g_string_append (command, "\"&");
                 system (command->str);
                 gnome_config_set_string ("/Screensaver/Default/command", command->str);
+                
                 g_string_free (command, TRUE);
         }
         if (dpms) {
@@ -646,7 +664,10 @@ try_callback ()
                 if (password)
                         g_string_append (command, " -lock-mode");
                 g_string_append (command," -xrm \"*programs:\t");
-                g_string_append (command, sd->args);
+                if (sd->args && *(sd->args)) 
+                        g_string_append (command, sd->args);
+                else
+                        g_string_append (command, sd->tryexec);
                 if (sd->root) {
                         g_string_append (command, " ");
                         g_string_append (command, sd->root);
@@ -699,7 +720,7 @@ revert_callback ()
         temp = gnome_config_get_string ("/Screensaver/Default/command=xscreensaver");
         if (!strchr(temp, '&')) {
                 /* ugh! */
-                temp2 = g_copy_strings (temp, " &", NULL);
+                temp2 = g_strconcat (temp, " &", NULL);
                 system (temp2);
                 g_free (temp2);
         } else {
