@@ -216,7 +216,7 @@ void set_range (setup_data *ssd)
                 snprintf (val, 100, " %f", (GTK_RANGE (ssd->widget))->adjustment->value);
                 gnome_config_set_float (ssd->name, (GTK_RANGE (ssd->widget))->adjustment->value);
         }
-        ssd->arg = g_copy_strings (ssd->flag1, val, NULL);
+        ssd->arg = g_strconcat (ssd->flag1, val, NULL);
 }
 static
 void set_check (setup_data *ssd)
@@ -286,7 +286,7 @@ get_entry (setup_data *ssd)
         entry = gtk_entry_new ();
         ssd->widget = entry;
         
-        prefix = g_copy_strings (ssd->name, "=", ssd->val_type, NULL);
+        prefix = g_strconcat (ssd->name, "=", ssd->val_type, NULL);
         val = gnome_config_get_string_with_default (prefix, NULL);
         //        g_print ("\tprefix:%s:\n",prefix);
 
@@ -304,9 +304,9 @@ get_entry (setup_data *ssd)
 
         /* set up the args */
         if (ssd->val_type)
-                ssd->arg = g_copy_strings (ssd->flag1, " \"", ssd->val_type, "\"", NULL);
+                ssd->arg = g_strconcat (ssd->flag1, " \"", ssd->val_type, "\"", NULL);
         else
-                ssd->arg = g_copy_strings (ssd->flag1, " \"\"", NULL);
+                ssd->arg = g_strconcat (ssd->flag1, " \"\"", NULL);
 
         if (frame) {
                 gtk_container_add (GTK_CONTAINER (frame), box);
@@ -338,7 +338,7 @@ get_range (setup_data *ssd, gint type)
         else
                 snprintf (temp, 24, "%f", adj->value);
         
-        prefix = g_copy_strings (ssd->name, "=", temp, NULL);
+        prefix = g_strconcat (ssd->name, "=", temp, NULL);
         //        g_print ("\tprefix:%s:\n",prefix);
         
         adj->value = gnome_config_get_int_with_default (prefix, NULL);
@@ -369,7 +369,7 @@ get_range (setup_data *ssd, gint type)
         }
 
         /* finally, we set the arg */
-        ssd->arg = g_copy_strings (ssd->flag1, " ", temp, NULL);
+        ssd->arg = g_strconcat (ssd->flag1, " ", temp, NULL);
 
         /* and return the widget */
         if (frame) {
@@ -389,7 +389,7 @@ get_check (setup_data *ssd)
         
         if (ssd->label)
                 frame = gtk_frame_new (ssd->label);
-        prefix = g_copy_strings (ssd->name, "=FALSE", NULL);
+        prefix = g_strconcat (ssd->name, "=FALSE", NULL);
         box = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
         gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
         check = gtk_check_button_new_with_label (ssd->left_label);
@@ -436,7 +436,7 @@ entry_callback (GtkEditable *editable, const gchar *text, gint length, gint *pos
         if (ssd->arg)
                 g_free (ssd->arg);
         
-        ssd->arg = g_copy_strings (ssd->flag1, " \"", gtk_entry_get_text (GTK_ENTRY (editable)),"\"", NULL);
+        ssd->arg = g_strconcat (ssd->flag1, " \"", gtk_entry_get_text (GTK_ENTRY (editable)),"\"", NULL);
         capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
 
 }
@@ -447,9 +447,9 @@ entry_delete_callback (GtkEditable *editable, gint length, gint *position, setup
                 g_free (ssd->arg);
         
         if (strlen (gtk_entry_get_text (GTK_ENTRY (editable))) > 0)
-                ssd->arg = g_copy_strings (ssd->flag1, " \"", gtk_entry_get_text (GTK_ENTRY (editable)),"\"", NULL);
+                ssd->arg = g_strconcat (ssd->flag1, " \"", gtk_entry_get_text (GTK_ENTRY (editable)),"\"", NULL);
         else
-                ssd->arg = g_copy_strings (ssd->flag1, " \"\"", NULL);
+                ssd->arg = g_strconcat (ssd->flag1, " \"\"", NULL);
         capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
 
 }
@@ -474,7 +474,7 @@ range_callback (GtkAdjustment *adj, setup_data *ssd)
                 snprintf (val, 100, " %d", (gint) adj->value);
         else
                 snprintf (val, 100, " %f", adj->value);
-        ssd->arg = g_copy_strings (ssd->flag1, val, NULL);
+        ssd->arg = g_strconcat (ssd->flag1, val, NULL);
         capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
 }
 
@@ -495,18 +495,21 @@ init_screensaver_data (screensaver_data *sd)
         setup_data *arg_vals;
 
         /* We set up the prefix for most of our gnome_config stuff. */
-        prefix = g_copy_strings ("=", sd->desktop_filename, "=", NULL);
+        prefix = g_strconcat ("=", sd->desktop_filename, "=", NULL);
         gnome_config_push_prefix (prefix);
-        
+        g_print ("prefix:%s:\n", prefix);
         /* We determine the current args */
-        tempstring = gnome_config_get_string ("Screensaver Data/DefaultFlags");
+        tempstring = gnome_config_get_string_with_default ("Screensaver Data/DefaultFlags", NULL);
+        g_print ("tempstring:%s:\n", tempstring);
         gnome_config_pop_prefix ();
-        tempstring2 = g_copy_strings ("/Screensaver/", sd->name, "/args=", tempstring ,NULL);
+        tempstring2 = g_strconcat ("/Screensaver/", sd->name, "/args=", tempstring ,NULL);
         g_free (tempstring);
-        tempstring = gnome_config_get_string (tempstring2);
+        sd->args = gnome_config_get_string_with_default (tempstring2, NULL);
+        if (sd->args)
+                g_print ("%s\nsd->args|%s|\n", tempstring2, sd->args);
+        else
+                g_print ("yea!\n"); 
         g_free (tempstring2);
-        sd->args = g_copy_strings (sd->tryexec, " ", tempstring, NULL);
-        g_free (tempstring);
 
         /* We determine the setup layout. */
         sec_iter = gnome_config_init_iterator_sections (prefix);
@@ -514,7 +517,7 @@ init_screensaver_data (screensaver_data *sd)
         while ((sec_iter = gnome_config_iterator_next (sec_iter, &sec, NULL))) {
                 if (strncmp ("Arg", sec, 3) == 0) {
                         arg_vals = new_arg_vals();
-                        tempstring = g_copy_strings (prefix, "/", sec, "/", NULL);
+                        tempstring = g_strconcat (prefix, "/", sec, "/", NULL);
                         val_iter = gnome_config_init_iterator (tempstring);
                         while ((val_iter = gnome_config_iterator_next (val_iter, &key, &value))) {
                                 parse_key (arg_vals, key, value);
@@ -525,7 +528,7 @@ init_screensaver_data (screensaver_data *sd)
                                 sd->setup_data = g_list_prepend (sd->setup_data, arg_vals);
                         /* FIXME: THIS IS REALLY ANNOYING!!! */
                         /* I don't know why this breaks, but this line here
-                         * seems to break the g_copy_strings a few lines earlier
+                         * seems to break the g_strconcat a few lines earlier
                          * on the next pass!!! */
                         /*else
                           free_setup_data (arg_vals);*/
@@ -544,7 +547,7 @@ get_screensaver_widget (screensaver_data *sd)
         gchar *prefix;
         
         vbox = gtk_vbox_new (FALSE, GNOME_PAD);
-        prefix = g_copy_strings ("/Screensaver/", sd->name, "/");
+        prefix = g_strconcat ("/Screensaver/", sd->name, "/");
         gnome_config_push_prefix (prefix);
         g_free (prefix);
         
@@ -584,7 +587,7 @@ store_screensaver_data (screensaver_data *sd)
         if (sd == NULL)
                 return;
 
-        prefix = g_copy_strings ("/Screensaver/", sd->name, "/", NULL);
+        prefix = g_strconcat ("/Screensaver/", sd->name, "/", NULL);
         gnome_config_push_prefix (prefix);
         g_free (prefix);
         if (sd->args)
@@ -614,5 +617,5 @@ store_screensaver_data (screensaver_data *sd)
 void
 free_screensaver_data (screensaver_data *sd)
 {
-        /* hmmm... I should write this (: */
+        /* FIXME: hmmm... I should write this (: */
 }
