@@ -51,12 +51,7 @@ exit_dialog_cancel_callback(GtkWidget *widget, gpointer data)
         gnome_dialog_close (GNOME_DIALOG (exit_dialog));
         exit_dialog = NULL;
 }
-void
-help_callback(GtkWidget *widget, gpointer data)
-{
-        /* nothing here yet, <: */
-        /* as per most gnome apps... */
-}
+
 void
 about_callback(GtkWidget *widget, gpointer data)
 {
