@@ -19,28 +19,23 @@ GtkWidget *splash_screen;
 gchar *init_cap = NULL;
 
 static GnomeUIInfo mainMenu[] = {
-        /*        {GNOME_APP_UI_HELP, NULL, NULL, NULL, NULL, NULL,
-                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},*/
-        {GNOME_APP_UI_ITEM, N_("_Quit"), NULL, exit_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 'q', GDK_CONTROL_MASK, NULL},
-        {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+        GNOMEUIINFO_MENU_EXIT_ITEM(exit_callback, NULL), 
+
+        GNOMEUIINFO_END
 };
 static GnomeUIInfo helpMenu[] = {
-        /*        {GNOME_APP_UI_HELP, NULL, NULL, NULL, NULL, NULL,
-                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},*/
-        {GNOME_APP_UI_ITEM, N_("_Help with GNOME..."), NULL, help_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("_About..."), NULL, about_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
-        {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+	GNOMEUIINFO_HELP("gnomecc"),
+
+        GNOMEUIINFO_MENU_ABOUT_ITEM(about_callback, NULL),
+
+        GNOMEUIINFO_END
 };
 static GnomeUIInfo parentMenu[] = {
-        {GNOME_APP_UI_SUBTREE, N_("_Main"), NULL, mainMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, helpMenu, NULL, NULL,
+        {GNOME_APP_UI_SUBTREE, N_("_Program"), NULL, mainMenu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+
+        GNOMEUIINFO_MENU_HELP_TREE(helpMenu),
+
         {GNOME_APP_UI_ENDOFINFO}
 };
 
@@ -138,12 +133,14 @@ create_window ()
         hpane = gtk_hpaned_new();
         gtk_paned_handle_size (GTK_PANED (hpane), 10);
         gtk_paned_gutter_size (GTK_PANED (hpane), 10);
-        tree = generate_tree();
+        tree = generate_tree ();
         sw = gtk_scrolled_window_new (GTK_CLIST (tree)->hadjustment, GTK_CLIST (tree)->vadjustment);
         gtk_widget_set_usize (sw, 175, 275);
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
         container = gtk_frame_new(NULL);
-        gtk_frame_set_shadow_type (GTK_FRAME (container), GTK_SHADOW_NONE);;
+        gtk_container_set_border_width (GTK_CONTAINER (container), 0);
+        gtk_frame_set_shadow_type (GTK_FRAME (container), GTK_SHADOW_IN);;
+
         splash_screen = gtk_drawing_area_new ();
         /*gdk_imlib_load_file_to_pixmap ("splash.png", &temp_splash, NULL);*/
         gtk_widget_set_usize (splash_screen, 300, 275);
