@@ -26,6 +26,8 @@ struct _node_data
 {
         GNOME_capplet capplet;
         GnomeDesktopEntry *gde;
+        GtkCTreeNode *node;
+        GtkCTree *ctree;
         GtkWidget *socket;
         GtkWidget *label;
         gint id;
